

/*
Author        : ZULQANI FAUZI
Created Date  : 05 / 07 / 2018
Updated Date  : 16 / 07 / 2018
*/

import {Component} from '@angular/core';
import {IonicPage, NavController, NavParams, AlertController, ToastController, ModalController} from 'ionic-angular';
import {AuthService} from "../../providers/auth-service";
import {Common} from "../../providers/common";
import {CalendarModal, CalendarModalOptions, CalendarResult} from "ion2-calendar";
import {IonPullUpFooterState} from 'ionic-pullup';

@IonicPage()
@Component({
  selector: 'page-rptpromo',
  templateUrl: 'rptpromo.html',
})
export class RptpromoPage {
shownGroup = null;
    toggleGroup(group) {
        if (this.isGroupShown(group)) {
            this.shownGroup = null;
        } else {
            this.shownGroup = group;
        }
    };
    isGroupShown(group) {
        return this.shownGroup === group;
    };
    footerState: IonPullUpFooterState;
    dataFilter = {
        dari: "",
        sampai: ""
    };
    dataKas = {
        nama: "",
        catatan: "",
        tanggal: "",
        jumlah: "",
        type: ""
    };
    resposeData: any;
    detailKas: any;
    logins: any[];
    items: any[] = [];
    itemsDtl: any[] = [];

    constructor(public modalCtrl: ModalController, public navCtrl: NavController,
        public navParams: NavParams,
        public alertCtrl: AlertController,
        public authService: AuthService,
        public common: Common,
        private toastCtrl: ToastController) {
        this.footerState = IonPullUpFooterState.Collapsed;
        this.dataFilter.dari = "";
        this.dataFilter.sampai = "";
        this.getPenjualanDtl();
    }

    openCalendar() {
        const options: CalendarModalOptions = {
            canBackwardsSelected: true,
            pickMode: 'range',
            title: 'Pilih Tanggal',
            defaultDate: new Date()
        };

        let myCalendar = this.modalCtrl.create(CalendarModal, {
            options: options
        });

        myCalendar.present();

        myCalendar.onDidDismiss((date: {from: CalendarResult; to: CalendarResult}, type: string) => {
            if (date === null) {
                this.dataFilter.dari = this.dataFilter.dari;
                this.dataFilter.sampai = this.dataFilter.sampai;
            } else {
                this.dataFilter.dari = date.from.string;
                this.dataFilter.sampai = date.to.string;
            }
        });
    }

    presentToast(msg) {
        let toast = this.toastCtrl.create({
            message: msg,
            duration: 3000
        });
        toast.present();
    }

    formatDate(date) {
        var d = new Date(date),
            month = '' + (d.getMonth() + 1),
            day = '' + d.getDate(),
            year = d.getFullYear();

        if (month.length < 2) month = '0' + month;
        if (day.length < 2) day = '0' + day;

        return [year, month, day].join('-');
    }


    getPenjualanDtl() {
        this.authService.postData(this.dataKas, "getTransaksiPenjualanDtl").then(
            result => {
                this.resposeData = result;
                if (this.resposeData.DataPenjualanDtl) {
                    this.detailKas = this.resposeData.DataPenjualanDtl;
                    for (let i = 0; i < this.resposeData.DataPenjualanDtl.length; i++) {
                        let TransID = this.resposeData.DataPenjualanDtl[i].TransID;
                        let TransDate = this.resposeData.DataPenjualanDtl[i].TransDate;
                        let nama_pelanggan = this.resposeData.DataPenjualanDtl[i].nama_depan + " " + this.resposeData.DataPenjualanDtl[i].nama_belakang;
                        let ItemID = this.resposeData.DataPenjualanDtl[i].ItemID;
                        let ItemName = this.resposeData.DataPenjualanDtl[i].ItemName;
                        let UOMName = this.resposeData.DataPenjualanDtl[i].UOMName;
                        let Qnty = this.resposeData.DataPenjualanDtl[i].Qnty;
                        let UnitPrice = this.resposeData.DataPenjualanDtl[i].UnitPrice;
                        let Total = Qnty * UnitPrice;
                        this.itemsDtl.push({
                            "TransID": TransID,
                            "TransDate": TransDate,
                            "nama_pelanggan": nama_pelanggan,
                            "ItemID": ItemID,
                            "ItemName": ItemName,
                            "UOMName": UOMName,
                            "Qnty": Qnty,
                            "UnitPrice": UnitPrice,
                            "Total": Total
                        });

                    }
                } else {

                }
            },
            err => {
                this.presentToast("Gagal terhubung ke server.");
            }
        );
    }
    filterData() {
        if (this.dataFilter.dari == "" && this.dataFilter.sampai == "") {
            this.presentToast("Silahkan pilih tanggal terlebih dahulu.");
        }
        else {
            this.items = [""];
            this.itemsDtl = [""];
            this.authService.postData(this.dataFilter, "getTransaksiPenjualanHdrFilter").then(
                result => {
                    this.resposeData = result;
                    if (this.resposeData.DataPenjualanHdr) {
                        this.getPenjualanDtl();
                        this.detailKas = this.resposeData.DataPenjualanHdr;
                        for (let i = 0; i < this.resposeData.DataPenjualanHdr.length; i++) {
                            let TransID = this.resposeData.DataPenjualanHdr[i].TransID;
                            let TransDate = this.resposeData.DataPenjualanHdr[i].TransDate;
                            let pengguna = this.resposeData.DataPenjualanHdr[i].CreatedBy;
                            let Remark = this.resposeData.DataPenjualanHdr[i].Remark;
                            let nama_pelanggan = this.resposeData.DataPenjualanHdr[i].nama_depan + " " + this.resposeData.DataPenjualanHdr[i].nama_belakang;
                            let Payment = this.resposeData.DataPenjualanHdr[i].Payment;
                            let Total = this.resposeData.DataPenjualanHdr[i].Total;
                            this.items.push({
                                "TransID": TransID,
                                "TransDate": TransDate,
                                "Remark": Remark,
                                "pengguna": pengguna,
                                "nama_pelanggan": nama_pelanggan,
                                "Payment": Payment,
                                "Total": Total,
                            });

                        }
                    } else {

                    }
                },
                err => {
                    this.presentToast("Gagal terhubung ke server.");
                }
            );
        }

    }
    ionViewDidLoad() {
        console.log('rptPenjualanPage');
    }
}
